Index: uspace/lib/usbvirt/src/ipc_dev.c
===================================================================
--- uspace/lib/usbvirt/src/ipc_dev.c	(revision 3be9d10120f7923a0b3d52282b8de0b670566c71)
+++ uspace/lib/usbvirt/src/ipc_dev.c	(revision 064e0fd3dd59d9aa7137ab66a590344cd891fddd)
@@ -49,16 +49,16 @@
  */
 static void ipc_get_name(usbvirt_device_t *dev,
-    cap_call_handle_t iid, ipc_call_t *icall)
+    cap_call_handle_t icall_handle, ipc_call_t *icall)
 {
 	if (dev->name == NULL) {
-		async_answer_0(iid, ENOENT);
+		async_answer_0(icall_handle, ENOENT);
 	}
 
 	size_t size = str_size(dev->name);
 
-	cap_call_handle_t callid;
+	cap_call_handle_t chandle;
 	size_t accepted_size;
-	if (!async_data_read_receive(&callid, &accepted_size)) {
-		async_answer_0(iid, EINVAL);
+	if (!async_data_read_receive(&chandle, &accepted_size)) {
+		async_answer_0(icall_handle, EINVAL);
 		return;
 	}
@@ -67,7 +67,7 @@
 		accepted_size = size;
 	}
-	async_data_read_finalize(callid, dev->name, accepted_size);
-
-	async_answer_1(iid, EOK, accepted_size);
+	async_data_read_finalize(chandle, dev->name, accepted_size);
+
+	async_answer_1(icall_handle, EOK, accepted_size);
 }
 
@@ -79,5 +79,5 @@
  */
 static void ipc_control_read(usbvirt_device_t *dev,
-    cap_call_handle_t iid, ipc_call_t *icall)
+    cap_call_handle_t icall_handle, ipc_call_t *icall)
 {
 	errno_t rc;
@@ -90,11 +90,11 @@
 	    1, 1024, 0, &setup_packet_len);
 	if (rc != EOK) {
-		async_answer_0(iid, rc);
-		return;
-	}
-
-	cap_call_handle_t data_callid;
-	if (!async_data_read_receive(&data_callid, &data_len)) {
-		async_answer_0(iid, EPARTY);
+		async_answer_0(icall_handle, rc);
+		return;
+	}
+
+	cap_call_handle_t data_chandle;
+	if (!async_data_read_receive(&data_chandle, &data_len)) {
+		async_answer_0(icall_handle, EPARTY);
 		free(setup_packet);
 		return;
@@ -103,5 +103,5 @@
 	void *buffer = malloc(data_len);
 	if (buffer == NULL) {
-		async_answer_0(iid, ENOMEM);
+		async_answer_0(icall_handle, ENOMEM);
 		free(setup_packet);
 		return;
@@ -113,6 +113,6 @@
 
 	if (rc != EOK) {
-		async_answer_0(data_callid, rc);
-		async_answer_0(iid, rc);
+		async_answer_0(data_chandle, rc);
+		async_answer_0(icall_handle, rc);
 		free(setup_packet);
 		free(buffer);
@@ -120,6 +120,6 @@
 	}
 
-	async_data_read_finalize(data_callid, buffer, actual_len);
-	async_answer_0(iid, EOK);
+	async_data_read_finalize(data_chandle, buffer, actual_len);
+	async_answer_0(icall_handle, EOK);
 
 	free(setup_packet);
@@ -134,5 +134,5 @@
  */
 static void ipc_control_write(usbvirt_device_t *dev,
-    cap_call_handle_t iid, ipc_call_t *icall)
+    cap_call_handle_t icall_handle, ipc_call_t *icall)
 {
 	size_t data_buffer_len = IPC_GET_ARG1(*icall);
@@ -146,5 +146,5 @@
 	    1, 0, 0, &setup_packet_len);
 	if (rc != EOK) {
-		async_answer_0(iid, rc);
+		async_answer_0(icall_handle, rc);
 		return;
 	}
@@ -154,5 +154,5 @@
 		    1, 0, 0, &data_buffer_len);
 		if (rc != EOK) {
-			async_answer_0(iid, rc);
+			async_answer_0(icall_handle, rc);
 			free(setup_packet);
 			return;
@@ -163,5 +163,5 @@
 	    data_buffer, data_buffer_len);
 
-	async_answer_0(iid, rc);
+	async_answer_0(icall_handle, rc);
 
 	free(setup_packet);
@@ -179,5 +179,5 @@
 static void ipc_data_in(usbvirt_device_t *dev,
     usb_transfer_type_t transfer_type,
-    cap_call_handle_t iid, ipc_call_t *icall)
+    cap_call_handle_t icall_handle, ipc_call_t *icall)
 {
 	usb_endpoint_t endpoint = IPC_GET_ARG1(*icall);
@@ -186,7 +186,7 @@
 
 	size_t data_len = 0;
-	cap_call_handle_t data_callid;
-	if (!async_data_read_receive(&data_callid, &data_len)) {
-		async_answer_0(iid, EPARTY);
+	cap_call_handle_t data_chandle;
+	if (!async_data_read_receive(&data_chandle, &data_len)) {
+		async_answer_0(icall_handle, EPARTY);
 		return;
 	}
@@ -194,5 +194,5 @@
 	void *buffer = malloc(data_len);
 	if (buffer == NULL) {
-		async_answer_0(iid, ENOMEM);
+		async_answer_0(icall_handle, ENOMEM);
 		return;
 	}
@@ -203,12 +203,12 @@
 
 	if (rc != EOK) {
-		async_answer_0(data_callid, rc);
-		async_answer_0(iid, rc);
+		async_answer_0(data_chandle, rc);
+		async_answer_0(icall_handle, rc);
 		free(buffer);
 		return;
 	}
 
-	async_data_read_finalize(data_callid, buffer, actual_len);
-	async_answer_0(iid, EOK);
+	async_data_read_finalize(data_chandle, buffer, actual_len);
+	async_answer_0(icall_handle, EOK);
 
 	free(buffer);
@@ -223,5 +223,5 @@
 static void ipc_data_out(usbvirt_device_t *dev,
     usb_transfer_type_t transfer_type,
-    cap_call_handle_t iid, ipc_call_t *icall)
+    cap_call_handle_t icall_handle, ipc_call_t *icall)
 {
 	usb_endpoint_t endpoint = IPC_GET_ARG1(*icall);
@@ -233,5 +233,5 @@
 	    1, 0, 0, &data_buffer_size);
 	if (rc != EOK) {
-		async_answer_0(iid, rc);
+		async_answer_0(icall_handle, rc);
 		return;
 	}
@@ -240,5 +240,5 @@
 	    data_buffer, data_buffer_size);
 
-	async_answer_0(iid, rc);
+	async_answer_0(icall_handle, rc);
 
 	free(data_buffer);
@@ -248,38 +248,38 @@
  *
  * @param dev Target USB device.
  * @param callid Caller id.
  * @param call Incoming call.
  * @return Whether the call was handled.
  */
 bool usbvirt_ipc_handle_call(usbvirt_device_t *dev,
-    cap_call_handle_t callid, ipc_call_t *call)
+    cap_call_handle_t chandle, ipc_call_t *call)
 {
 	switch (IPC_GET_IMETHOD(*call)) {
 	case IPC_M_USBVIRT_GET_NAME:
-		ipc_get_name(dev, callid, call);
+		ipc_get_name(dev, chandle, call);
 		break;
 
 	case IPC_M_USBVIRT_CONTROL_READ:
-		ipc_control_read(dev, callid, call);
+		ipc_control_read(dev, chandle, call);
 		break;
 
 	case IPC_M_USBVIRT_CONTROL_WRITE:
-		ipc_control_write(dev, callid, call);
+		ipc_control_write(dev, chandle, call);
 		break;
 
 	case IPC_M_USBVIRT_INTERRUPT_IN:
-		ipc_data_in(dev, USB_TRANSFER_INTERRUPT, callid, call);
+		ipc_data_in(dev, USB_TRANSFER_INTERRUPT, chandle, call);
 		break;
 
 	case IPC_M_USBVIRT_BULK_IN:
-		ipc_data_in(dev, USB_TRANSFER_BULK, callid, call);
+		ipc_data_in(dev, USB_TRANSFER_BULK, chandle, call);
 		break;
 
 	case IPC_M_USBVIRT_INTERRUPT_OUT:
-		ipc_data_out(dev, USB_TRANSFER_INTERRUPT, callid, call);
+		ipc_data_out(dev, USB_TRANSFER_INTERRUPT, chandle, call);
 		break;
 
 	case IPC_M_USBVIRT_BULK_OUT:
-		ipc_data_out(dev, USB_TRANSFER_BULK, callid, call);
+		ipc_data_out(dev, USB_TRANSFER_BULK, chandle, call);
 		break;
 
@@ -248,38 +248,38 @@
  *
  * @param dev Target USB device.
- * @param callid Caller id.
+ * @param chandle Caller id.
  * @param call Incoming call.
  * @return Whether the call was handled.
